from .sample_data import adh_san_diego, elevation_nl, xoxo
from .synthetic import disk, generate_disk
